@@ -116,7 +116,7 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
+#define HAVE_HIST_ENTRY 1
 /* #undef USE_LIBEDIT_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 
@@ -335,7 +335,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -396,8 +396,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "powerpc"
-#define DEFAULT_MACHINE "powerpc"
+#define MACHINE_TYPE "earmv7hf"
+#define DEFAULT_MACHINE "earmv7hf"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -533,16 +533,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 20
+#define MYSQL_VERSION_PATCH 21
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.20"
+#define PACKAGE_STRING "MySQL Server 10.6.21"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.20"
-#define VERSION "10.6.20"
+#define PACKAGE_VERSION "10.6.21"
+#define VERSION "10.6.21"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
